Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(804)

Unified Diff: scripts/big5_gen.sh

Issue 1514253003: Converter update for Big5, KOI8-U and timezone update to 2015g (Closed) Base URL: https://chromium.googlesource.com/chromium/deps/icu.git@master
Patch Set: readme update Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « android/icudtl.dat ('k') | source/data/in/icudtl.dat » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/big5_gen.sh
diff --git a/scripts/big5_gen.sh b/scripts/big5_gen.sh
index 7b57d525ffc43dd8db46f94ba14f33a0d9246a6e..1e19964246cc5e2dce5259ab0eea57f8aa56656f 100644
--- a/scripts/big5_gen.sh
+++ b/scripts/big5_gen.sh
@@ -59,8 +59,10 @@ function ascii {
# HKSCS characters are not supported in encoding ( |lead < 0xA1| )
# Entries with pointer=528[79] have to be decoding-only even though
# come before the other entry with the same Unicode character.
# See https://www.w3.org/Bugs/Public/show_bug.cgi?id=27878
function big5 {
awk '!/^#/ && !/^$/ \
@@ -69,7 +71,8 @@ function big5 {
sortkey = (length(ucs) < 5) ? ("0" ucs) : ucs;
lead = pointer / 157 + 0x81; \
is_decoding_only = lead < 0xA1 || seen_before[ucs] || \
- pointer == 5287 || pointer == 5289; \
+ pointer == 5287 || pointer == 5289 || \
+ (5247 <= pointer && pointer <= 5250);
trail = $1 % 157; \
trail_offset = trail < 0x3F ? 0x40 : 0x62; \
tag = (is_decoding_only ? 3 : 0); \
@@ -59,8 +59,10 @@ function ascii {
# HKSCS characters are not supported in encoding ( |lead < 0xA1| )
-# Entries with pointer=528[79] have to be decoding-only even though
-# come before the other entry with the same Unicode character.
+# Entries with pointer=528[79] and 5247 ~ 5250 have to be decoding-only
+# even though they come before the other entry with the same Unicode
+# character. The corresponding Unicode characters are U+255[0E],
+# U+256[1A], and U+534[15].
# See https://www.w3.org/Bugs/Public/show_bug.cgi?id=27878
function big5 {
« no previous file with comments | « android/icudtl.dat ('k') | source/data/in/icudtl.dat » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698